@@ -26,15 +26,11 @@ describe 'watcher' do
       end
 
       it { is_expected.to contain_class('watcher::policy') }
+      it { is_expected.to contain_class('watcher::deps') }
 
       it 'configures rabbit' do
         is_expected.to contain_watcher_config('DEFAULT/rpc_backend').with_value('rabbit')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_password').with_value('<SERVICE DEFAULT>').with_secret(true)
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_userid').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_login_method').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_retry_interval').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_retry_backoff').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_interval_max').with_value('<SERVICE DEFAULT>')
@@ -63,10 +59,6 @@ describe 'watcher' do
       let :params do
         {
           :default_transport_url              => 'rabbit://rabbit_user:password@localhost:5673',
-          :rabbit_host                        => 'rabbit',
-          :rabbit_userid                      => 'rabbit_user',
-          :rabbit_port                        => '5673',
-          :rabbit_password                    => 'password',
           :rabbit_ha_queues                   => 'undef',
           :rabbit_heartbeat_timeout_threshold => '60',
           :rabbit_heartbeat_rate              => '10',
@@ -79,11 +71,6 @@ describe 'watcher' do
       it 'configures rabbit' do
         is_expected.to contain_watcher_config('DEFAULT/rpc_backend').with_value('rabbit')
         is_expected.to contain_watcher_config('DEFAULT/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_host').with_value('rabbit')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_password').with_value('password').with_secret(true)
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_port').with_value('5673')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_userid').with_value('rabbit_user')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_watcher_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('60')
         is_expected.to contain_watcher_config('oslo_messaging_rabbit/heartbeat_rate').with_value('10')
         is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_login_method').with_value('<SERVICE DEFAULT>')
@@ -102,41 +89,7 @@ describe 'watcher' do
 
     end
 
-    context 'with rabbit_hosts parameter' do
-      let :params do
-        { :rabbit_hosts => ['rabbit:5673', 'rabbit2:5674'] }
-      end
-
-      it 'configures rabbit' do
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_hosts').with_value('rabbit:5673,rabbit2:5674')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(true)
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>')
-      end
-    end
-
-    context 'with rabbit_hosts parameter (one server)' do
-      let :params do
-        { :rabbit_hosts => ['rabbit:5673'] }
-      end
-
-      it 'configures rabbit' do
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_hosts').with_value('rabbit:5673')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/kombu_missing_consumer_retry_timeout').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>')
-      end
-    end
-
-    context 'with kombu_reconnect_delay set to 5.0' do
+   context 'with kombu_reconnect_delay set to 5.0' do
       let :params do
         { :kombu_reconnect_delay => '5.0' }
       end
@@ -156,10 +109,9 @@ describe 'watcher' do
       end
     end
 
-    context 'with rabbit_ha_queues set to false and with rabbit_hosts' do
+    context 'with rabbit_ha_queues set to false' do
       let :params do
-        { :rabbit_ha_queues => 'false',
-          :rabbit_hosts => ['rabbit:5673'] }
+        { :rabbit_ha_queues => 'false' }
       end
 
       it 'configures rabbit' do
@@ -169,14 +121,10 @@ describe 'watcher' do
 
     context 'with amqp_durable_queues parameter' do
       let :params do
-        { :rabbit_hosts => ['rabbit:5673'],
-          :amqp_durable_queues => 'true' }
+        { :amqp_durable_queues => 'true' }
       end
 
       it 'configures rabbit' do
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_hosts').with_value('rabbit:5673')
         is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_watcher_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(true)
@@ -185,8 +133,7 @@ describe 'watcher' do
 
     context 'with rabbit ssl enabled with kombu' do
       let :params do
-        { :rabbit_hosts       => ['rabbit:5673'],
-          :rabbit_use_ssl     => true,
+        { :rabbit_use_ssl     => true,
           :kombu_ssl_ca_certs => '/etc/ca.cert',
           :kombu_ssl_certfile => '/etc/certfile',
           :kombu_ssl_keyfile  => '/etc/key',
@@ -204,8 +151,7 @@ describe 'watcher' do
 
     context 'with rabbit ssl enabled without kombu' do
       let :params do
-        { :rabbit_hosts       => ['rabbit:5673'],
-          :rabbit_use_ssl     => true, }
+        { :rabbit_use_ssl     => true, }
       end
 
       it 'configures rabbit' do
@@ -219,12 +165,14 @@ describe 'watcher' do
 
     context 'with amqp rpc_backend' do
       let :params do
-        { :rpc_backend => 'amqp' }
+        { :rpc_backend => 'amqp',
+          :default_transport_url => 'amqp://amqp_user:password@localhost:5672', }
       end
 
       context 'with default parameters' do
         it 'configures amqp' do
           is_expected.to contain_watcher_config('DEFAULT/rpc_backend').with_value('amqp')
+          is_expected.to contain_watcher_config('DEFAULT/transport_url').with_value('amqp://amqp_user:password@localhost:5672')
           is_expected.to contain_watcher_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>')
           is_expected.to contain_watcher_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>')
           is_expected.to contain_watcher_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>')
