@@ -48,7 +48,6 @@ describe 'watcher::keystone::authtoken' do
         is_expected.to contain_watcher_config('keystone_authtoken/memcached_servers').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_watcher_config('keystone_authtoken/region_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_watcher_config('keystone_authtoken/revocation_cache_time').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('keystone_authtoken/signing_dir').with_value('/var/cache/watcher')
         is_expected.to contain_watcher_config('keystone_authtoken/token_cache_time').with_value('<SERVICE DEFAULT>')
       end
     end
@@ -87,9 +86,9 @@ describe 'watcher::keystone::authtoken' do
           :memcache_security_strategy           => 'ENCRYPT',
           :memcache_use_advanced_pool           => true,
           :memcached_servers                    => ['memcached01:11211','memcached02:11211'],
+          :manage_memcache_package              => true,
           :region_name                          => 'region2',
           :revocation_cache_time                => '11',
-          :signing_dir                          => '/var/cache',
           :token_cache_time                     => '301',
         })
       end
@@ -128,9 +127,12 @@ describe 'watcher::keystone::authtoken' do
         is_expected.to contain_watcher_config('keystone_authtoken/memcached_servers').with_value('memcached01:11211,memcached02:11211')
         is_expected.to contain_watcher_config('keystone_authtoken/region_name').with_value(params[:region_name])
         is_expected.to contain_watcher_config('keystone_authtoken/revocation_cache_time').with_value(params[:revocation_cache_time])
-        is_expected.to contain_watcher_config('keystone_authtoken/signing_dir').with_value(params[:signing_dir])
         is_expected.to contain_watcher_config('keystone_authtoken/token_cache_time').with_value(params[:token_cache_time])
       end
+
+      it 'installs python memcache package' do
+        is_expected.to contain_package('python-memcache')
+      end
     end
   end
 
